Toil is a scalable, efficient, cross-platform pipeline management system, written entirely in
Python, and designed around the principles of functional programming. Full documentation can be found at `Read the Docs`_.

.. _Read the Docs: http://toil.readthedocs.org/en/latest/


